//Bibliotheken laden
#include <Wire.h>
#include <SPI.h>
#include <nRF24L01.h>
#include <RF24.h>

//Bibliotheken für den betrieb des Displays
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define OLED_RESET 4
Adafruit_SSD1306 display(OLED_RESET);

//CE - digitaler Pin D6
//CSN - digitaler Pin D7
RF24 radio(6, 7);  // CE, CSN

//Adresse über welche die Kommunikation stattfinden soll
const byte address[6] = "00001";

void setup() {
  //solange der serielle Port nicht initialisiert ist
  //soll ein leere Schleife ausgeführt werden
  while (!Serial);

  //beginn der seriellen Kommunikation mit 9600baud
  Serial.begin(9600);

  radio.begin();

  //setzen der Adresse
  //es können mehr als eine Adresse verwendet werden
  radio.openReadingPipe(0, address);

  //starten des "abhören"
  radio.startListening();

  //initialisieren des Displays
  display.begin(SSD1306_SWITCHCAPVCC, 0x3C);
  display.display();
  delay(1000);
  display.setTextSize(1);
  display.setTextColor(WHITE);
}

void loop() {
  //Wenn Daten empfangen wurden, dann...
  if (radio.available()) {
    display.clearDisplay();
    //einen Buffer für den gelesen Text initialisieren
    char text[200] = {0};
    //lesen der Daten in den Buffer
    radio.read(&text, sizeof(text));

    //Umwandeln des char Arrays in ein String
    String jsonLine = String(text);
    //parsen des Textes
    parseAndDisplayText(jsonLine);
  }
}

void parseAndDisplayText(String jsonLine) {
  //Wenn das JSON komplett empfangen wurde, dann...
  if (jsonLine.startsWith("{") && jsonLine.endsWith("}")) {

    //Variablen um die Temperatur & die rel. Luftfeuchtigkeit zu speichern
    String temp = "";
    String hum = "";

    //zunächst schneiden wir das erste und letze Zeichen ab (die geschweiften Klammern)
    String subStr = jsonLine.substring(1, jsonLine.length() - 1);

    //Als trenner zwischen den Werten haben wir ein Komma, dieses suchen wir nun
    for (int i = 0; i <= subStr.length(); i++) {
      //Wenn das Komma gefunden wurde, dann...
      if (subStr.charAt(i) == ',') {
        //die Temperatur ist an der ersten Stelle, wird aber durch "t:" eingeleitet welches wird auch abschneiden,
        temp = subStr.substring(2, i);
        //die rel. Luftfeuchtigkeit ist an der zweiten Stelle und wird durch "h:" eingeleitet, zusätzlich müssen
        //wir noch das Komma mit abschneiden
        hum = subStr.substring(i + 3, subStr.length());
        break;
      }
    }

    //anzeigen der Daten auf dem Display
    displayLine(0, "Temperatur: " + temp + "C");
    displayLine(1, "Luftfeuchte: " + hum + "%");
  }
}

void displayLine(int zeile, String text) {
  display.setCursor(0, zeile * 10);
  display.println(text);
  display.display();
}
